@@ -1,5 +1,4 @@
 #![allow(deprecated)]
-#![doc = include_str!("../README.md")]
 #![cfg_attr(feature = "dox", feature(doc_cfg))]
 
 pub use ffi;
@@ -48,6 +47,4 @@ pub use web_view::*;
 #[cfg_attr(feature = "dox", doc(cfg(feature = "v2_16")))]
 pub use website_data_manager::*;
 
-pub use crate::auto::builders::*;
-pub use crate::auto::traits::*;
 pub use crate::auto::*;
